﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Media;

namespace GanttChartTaskListViewBarTemplatingSample
{
    // Defines a attached properties to be used for specifying custom item settings in markup.
    public static class ItemExtensions
    {
        // The icon to be displayed on the task bar.
        public static DependencyProperty IconProperty = DependencyProperty.RegisterAttached("Icon", typeof(ImageSource), typeof(ItemExtensions), new FrameworkPropertyMetadata());
        public static ImageSource GetIcon(DependencyObject d)
        {
            return (ImageSource)d.GetValue(IconProperty);
        }
        public static void SetIcon(DependencyObject d, ImageSource value)
        {
            d.SetValue(IconProperty, value);
        }

        // The note to be displayed under the task bar.
        public static DependencyProperty NoteProperty = DependencyProperty.RegisterAttached("Note", typeof(string), typeof(ItemExtensions), new FrameworkPropertyMetadata());
        public static string GetNote(DependencyObject d)
        {
            return (string)d.GetValue(NoteProperty);
        }
        public static void SetNote(DependencyObject d, string value)
        {
            d.SetValue(NoteProperty, value);
        }

        // The date that a task is estimated to start on.
        public static DependencyProperty EstimatedStartProperty = DependencyProperty.RegisterAttached("EstimatedStart", typeof(DateTime), typeof(ItemExtensions), new FrameworkPropertyMetadata());
        public static DateTime GetEstimatedStart(DependencyObject d)
        {
            return (DateTime)d.GetValue(EstimatedStartProperty);
        }
        public static void SetEstimatedStart(DependencyObject d, DateTime value)
        {
            d.SetValue(EstimatedStartProperty, value);
        }

        // The date that a task is estimated to finish on.
        public static DependencyProperty EstimatedFinishProperty = DependencyProperty.RegisterAttached("EstimatedFinish", typeof(DateTime), typeof(ItemExtensions), new FrameworkPropertyMetadata());
        public static DateTime GetEstimatedFinish(DependencyObject d)
        {
            return (DateTime)d.GetValue(EstimatedFinishProperty);
        }
        public static void SetEstimatedFinish(DependencyObject d, DateTime value)
        {
            d.SetValue(EstimatedFinishProperty, value);
        }

        // A list of marker icons to be displayed on the task bar at specific dates and times.
        public static DependencyProperty MarkersProperty = DependencyProperty.RegisterAttached("Markers", typeof(MarkerCollection), typeof(ItemExtensions), new FrameworkPropertyMetadata());
        public static MarkerCollection GetMarkers(DependencyObject d)
        {
            return (MarkerCollection)d.GetValue(IconProperty);
        }
        public static void SetMarkers(DependencyObject d, MarkerCollection value)
        {
            d.SetValue(IconProperty, value);
        }
    }
}
